==> ckan-2.7.2.tar.gz: ckan-2.7.2/ckan/public/base/i18n/mn_MN.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "mn_MN", 
    "plural-forms": "nplurals=2; plural=(n != 1);"
  }, 
  "An Error Occurred": [
    null, 
    "Алдаа гарлаа"
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "Та тус үйлдлийг гүйцэтгэхдээ итгэлтэй байна уу?"
  ], 
  "Cancel": [
    null, 
    "Цуцлах"
  ], 
  "Confirm": [
    null, 
    "Зөвшөөрөх"
  ], 
  "Edit": [
    null, 
    "Засварлах"
  ], 
  "Failed to load data API information": [
    null, 
    "Өгөгдлийн API мэдээллийг ачааллахад алдаа гарлаа"
  ], 
  "File": [
    null, 
    "Файл"
  ], 
  "Follow": [
    null, 
    "Дагах"
  ], 
  "Hide": [
    null, 
    "Нуух"
  ], 
  "Image": [
    null, 
    "Зураг"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "", 
    ""
  ], 
  "Link": [
    null, 
    "Холбоос"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "Интернетэд байрлах замтай холбох (мөн API-тай холбож болно)"
  ], 
  "Loading...": [
    null, 
    "Ачааллаж байна..."
  ], 
  "No matches found": [
    null, 
    "Тохирох зүйл олдсонгүй"
  ], 
  "Please Confirm Action": [
    null, 
    "Үйлдлээ баталгаажуулна уу"
  ], 
  "Remove": [
    null, 
    "Устгах"
  ], 
  "Resource uploaded": [
    null, 
    "Материал хуулагдлаа"
  ], 
  "Save order": [
    null, 
    "Дарааллыг хадгалах"
  ], 
  "Saving...": [
    null, 
    "Хадгалж байна.."
  ], 
  "Show more": [
    null, 
    "Дэлгэрэнгүй"
  ], 
  "Start typing…": [
    null, 
    "Бичиж эхлэнэ үү..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "Энэ маягтанд хадгалагдаагүй өөрчлөлтүүд байна."
  ], 
  "There is no API data to load for this resource": [
    null, 
    "Тус материалыг ачааллах API өгөгдөл байхгүй байна"
  ], 
  "URL": [
    null, 
    "URL"
  ], 
  "Unable to authenticate upload": [
    null, 
    "Хуулах эрхийг баталгаажуулах боломжгүй байна"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "Хуулсан файлын мэдээллийг авах боломжгүй"
  ], 
  "Unable to upload file": [
    null, 
    "Файлыг хуулах боломжгүй байна"
  ], 
  "Unfollow": [
    null, 
    "Дагахаа болих"
  ], 
  "Upload": [
    null, 
    "Хуулах"
  ], 
  "Upload a file": [
    null, 
    "Файл хуулах"
  ], 
  "Upload a file on your computer": [
    null, 
    "Компьютерээс файл хуулах"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "Та яг одоо файл хуулж байна. Хуулж байгаа файлаа зогсоогоод гарахдаа итгэлтэй байна уу."
  ]
}

==> ckan-2.8.1.tar.gz: ckan-2.8.1/ckan/public/base/i18n/mn_MN.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "mn_MN", 
    "plural-forms": "nplurals=2; plural=(n != 1);"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    "", 
    ""
  ], 
  "%(num)d item": [
    "%(num)d items", 
    "", 
    ""
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    "", 
    ""
  ], 
  "Add Filter": [
    null, 
    "Шүүлтүүр нэмэх"
  ], 
  "An Error Occurred": [
    null, 
    "Алдаа гарлаа"
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "Та тус үйлдлийг гүйцэтгэхдээ итгэлтэй байна уу?"
  ], 
  "Cancel": [
    null, 
    "Цуцлах"
  ], 
  "Confirm": [
    null, 
    "Зөвшөөрөх"
  ], 
  "Could not load view": [
    null, 
    "Харагдацыг ачаалж чадсангүй"
  ], 
  "DataProxy returned an error": [
    null, 
    "Өгөгдлийн прокси алдаа буцаалаа"
  ], 
  "DataStore returned an error": [
    null, 
    "Өгөгдлийн нөөц алдаа буцаалаа"
  ], 
  "Edit": [
    null, 
    "Засварлах"
  ], 
  "Failed to load data API information": [
    null, 
    "Өгөгдлийн API мэдээллийг ачааллахад алдаа гарлаа"
  ], 
  "File": [
    null, 
    "Файл"
  ], 
  "Filters": [
    null, 
    "Шүүлтүүр"
  ], 
  "Follow": [
    null, 
    "Дагах"
  ], 
  "Graph": [
    null, 
    "Граф"
  ], 
  "Grid": [
    null, 
    "Хүснэгт"
  ], 
  "Hide": [
    null, 
    "Нуух"
  ], 
  "Image": [
    null, 
    "Зураг"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "", 
    ""
  ], 
  "Link": [
    null, 
    "Холбоос"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "Интернетэд байрлах замтай холбох (мөн API-тай холбож болно)"
  ], 
  "Loading...": [
    null, 
    "Ачааллаж байна..."
  ], 
  "Map": [
    null, 
    "Газрын зураг"
  ], 
  "No matches found": [
    null, 
    "Тохирох зүйл олдсонгүй"
  ], 
  "Please Confirm Action": [
    null, 
    "Үйлдлээ баталгаажуулна уу"
  ], 
  "Remove": [
    null, 
    "Устгах"
  ], 
  "Resource uploaded": [
    null, 
    "Материал хуулагдлаа"
  ], 
  "Save order": [
    null, 
    "Дарааллыг хадгалах"
  ], 
  "Saving...": [
    null, 
    "Хадгалж байна.."
  ], 
  "Select a field": [
    null, 
    "Талбарыг сонгох"
  ], 
  "Show more": [
    null, 
    "Дэлгэрэнгүй"
  ], 
  "Start typing…": [
    null, 
    "Бичиж эхлэнэ үү..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "Энэ маягтанд хадгалагдаагүй өөрчлөлтүүд байна."
  ], 
  "There is no API data to load for this resource": [
    null, 
    "Энэ нөөцийг ачааллах API өгөгдөл байхгүй байна"
  ], 
  "URL": [
    null, 
    "URL"
  ], 
  "Unable to authenticate upload": [
    null, 
    "Хуулах эрхийг баталгаажуулах боломжгүй байна"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "Хуулсан файлын мэдээллийг авах боломжгүй"
  ], 
  "Unable to upload file": [
    null, 
    "Файлыг хуулах боломжгүй байна"
  ], 
  "Unfollow": [
    null, 
    "Дагахаа болих"
  ], 
  "Upload": [
    null, 
    "Хуулах"
  ], 
  "Upload a file": [
    null, 
    "Файл хуулах"
  ], 
  "Upload a file on your computer": [
    null, 
    "Компьютерээс файл хуулах"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "Та яг одоо файл хуулж байна. Хуулж байгаа файлаа зогсоогоод гарахдаа итгэлтэй байна уу."
  ], 
  "bar": [
    "bars", 
    "", 
    ""
  ], 
  "error loading view": [
    null, 
    "харагдацыг ачаалах үеийн алдаа"
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    "", 
    ""
  ], 
  "no translation": [
    "no translations", 
    "", 
    ""
  ]
}
